@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: netload.c,v 1.8 1999/07/30 21:03:19 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,7 +43,7 @@ int
 main (int argc, char *argv [])
 {
 	glibtop_netload netload;
-	unsigned method, count, port, i;
+	unsigned method, count, port;
 	struct in_addr addr, subnet;
 	char *address_string, *subnet_string;
 	char buffer [BUFSIZ];
