@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: smp.c,v 1.5 1999/08/19 20:12:23 sopwith Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,8 +27,6 @@
 #include <glibtop/cpu.h>
 #include <glibtop/xmalloc.h>
 
-#include <math.h>
-
 int
 main (int argc, char *argv [])
 {
@@ -67,7 +65,7 @@ main (int argc, char *argv [])
 	memset (separator, '-', 91);
 	separator [92] = '\0';
 
-	sprintf (buffer, _("Ticks (%d per second):"), frequency);
+	sprintf (buffer, _("Ticks (%ld per second):"), frequency);
 
 	printf ("\n\n%-26s %12s %12s %12s %12s %12s\n%s\n", buffer,
 		_("Total"), _("User"), _("Nice"), _("Sys"), _("Idle"), separator);
