@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: sysdeps.c,v 1.7 1999/07/30 21:03:19 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -38,7 +38,7 @@ int
 main (int argc, char *argv [])
 {
 	glibtop_sysdeps sysdeps;
-	unsigned method, count, port, i;
+	unsigned method, count, port;
 	char buffer [BUFSIZ];
 
 	count = PROFILE_COUNT;
