@@ -25,36 +25,12 @@ glibtop_guile_get_cpu (void)
 			gh_ulong2scm  (cpu.sys),
 			gh_ulong2scm  (cpu.idle),
 			gh_ulong2scm  (cpu.frequency),
-			gh_list
-			(gh_ulong2scm  (cpu.xcpu_total [0]),
-			 gh_ulong2scm  (cpu.xcpu_total [1]),
-			 gh_ulong2scm  (cpu.xcpu_total [2]),
-			 gh_ulong2scm  (cpu.xcpu_total [3]),
-			 SCM_UNDEFINED),
-			gh_list
-			(gh_ulong2scm  (cpu.xcpu_user [0]),
-			 gh_ulong2scm  (cpu.xcpu_user [1]),
-			 gh_ulong2scm  (cpu.xcpu_user [2]),
-			 gh_ulong2scm  (cpu.xcpu_user [3]),
-			 SCM_UNDEFINED),
-			gh_list
-			(gh_ulong2scm  (cpu.xcpu_nice [0]),
-			 gh_ulong2scm  (cpu.xcpu_nice [1]),
-			 gh_ulong2scm  (cpu.xcpu_nice [2]),
-			 gh_ulong2scm  (cpu.xcpu_nice [3]),
-			 SCM_UNDEFINED),
-			gh_list
-			(gh_ulong2scm  (cpu.xcpu_sys [0]),
-			 gh_ulong2scm  (cpu.xcpu_sys [1]),
-			 gh_ulong2scm  (cpu.xcpu_sys [2]),
-			 gh_ulong2scm  (cpu.xcpu_sys [3]),
-			 SCM_UNDEFINED),
-			gh_list
-			(gh_ulong2scm  (cpu.xcpu_idle [0]),
-			 gh_ulong2scm  (cpu.xcpu_idle [1]),
-			 gh_ulong2scm  (cpu.xcpu_idle [2]),
-			 gh_ulong2scm  (cpu.xcpu_idle [3]),
-			 SCM_UNDEFINED),
+			gh_ulong2scm  (cpu.xcpu_total[GLIBTOP_NCPU]),
+			gh_ulong2scm  (cpu.xcpu_user[GLIBTOP_NCPU]),
+			gh_ulong2scm  (cpu.xcpu_nice[GLIBTOP_NCPU]),
+			gh_ulong2scm  (cpu.xcpu_sys[GLIBTOP_NCPU]),
+			gh_ulong2scm  (cpu.xcpu_idle[GLIBTOP_NCPU]),
+			gh_ulong2scm  (cpu.xcpu_flags),
 			SCM_UNDEFINED);
 
 	return list;
@@ -118,6 +94,7 @@ glibtop_guile_get_uptime (void)
 	list = gh_list (gh_ulong2scm  (uptime.flags),
 			gh_double2scm (uptime.uptime),
 			gh_double2scm (uptime.idletime),
+			gh_ulong2scm  (uptime.boot_time),
 			SCM_UNDEFINED);
 
 	return list;
@@ -261,9 +238,14 @@ glibtop_guile_get_proc_state (SCM pid)
 
 	list = gh_list (gh_ulong2scm  (proc_state.flags),
 			gh_str02scm   (proc_state.cmd),
-			gh_char2scm   (proc_state.state),
+			 (proc_state.state),
 			gh_ulong2scm  (proc_state.uid),
 			gh_ulong2scm  (proc_state.gid),
+			gh_ulong2scm  (proc_state.ruid),
+			gh_ulong2scm  (proc_state.rgid),
+			gh_ulong2scm  (proc_state.has_cpu),
+			gh_ulong2scm  (proc_state.processor),
+			gh_ulong2scm  (proc_state.last_processor),
 			SCM_UNDEFINED);
 
 	return list;
@@ -284,6 +266,10 @@ glibtop_guile_get_proc_uid (SCM pid)
 			gh_long2scm   (proc_uid.euid),
 			gh_long2scm   (proc_uid.gid),
 			gh_long2scm   (proc_uid.egid),
+			gh_long2scm   (proc_uid.suid),
+			gh_long2scm   (proc_uid.sgid),
+			gh_long2scm   (proc_uid.fsuid),
+			gh_long2scm   (proc_uid.fsgid),
 			gh_long2scm   (proc_uid.pid),
 			gh_long2scm   (proc_uid.ppid),
 			gh_long2scm   (proc_uid.pgrp),
@@ -292,6 +278,8 @@ glibtop_guile_get_proc_uid (SCM pid)
 			gh_long2scm   (proc_uid.tpgid),
 			gh_long2scm   (proc_uid.priority),
 			gh_long2scm   (proc_uid.nice),
+			gh_long2scm   (proc_uid.ngroups),
+			gh_long2scm   (proc_uid.groups[GLIBTOP_MAX_GROUPS]),
 			SCM_UNDEFINED);
 
 	return list;
@@ -339,18 +327,9 @@ glibtop_guile_get_proc_time (SCM pid)
 			gh_long2scm   (proc_time.timeout),
 			gh_long2scm   (proc_time.it_real_value),
 			gh_long2scm   (proc_time.frequency),
-			gh_list
-			(gh_long2scm   (proc_time.xcpu_utime [0]),
-			 gh_long2scm   (proc_time.xcpu_utime [1]),
-			 gh_long2scm   (proc_time.xcpu_utime [2]),
-			 gh_long2scm   (proc_time.xcpu_utime [3]),
-			 SCM_UNDEFINED),
-			gh_list
-			(gh_long2scm   (proc_time.xcpu_stime [0]),
-			 gh_long2scm   (proc_time.xcpu_stime [1]),
-			 gh_long2scm   (proc_time.xcpu_stime [2]),
-			 gh_long2scm   (proc_time.xcpu_stime [3]),
-			 SCM_UNDEFINED),
+			gh_long2scm   (proc_time.xcpu_utime[GLIBTOP_NCPU]),
+			gh_long2scm   (proc_time.xcpu_stime[GLIBTOP_NCPU]),
+			gh_long2scm   (proc_time.xcpu_flags),
 			SCM_UNDEFINED);
 
 	return list;
@@ -431,7 +410,16 @@ glibtop_guile_get_proc_segment (SCM pid)
 			gh_ulong2scm  (proc_segment.dirty_size),
 			gh_ulong2scm  (proc_segment.start_code),
 			gh_ulong2scm  (proc_segment.end_code),
+			gh_ulong2scm  (proc_segment.start_data),
+			gh_ulong2scm  (proc_segment.end_data),
+			gh_ulong2scm  (proc_segment.start_brk),
+			gh_ulong2scm  (proc_segment.end_brk),
 			gh_ulong2scm  (proc_segment.start_stack),
+			gh_ulong2scm  (proc_segment.start_mmap),
+			gh_ulong2scm  (proc_segment.arg_start),
+			gh_ulong2scm  (proc_segment.arg_end),
+			gh_ulong2scm  (proc_segment.env_start),
+			gh_ulong2scm  (proc_segment.env_end),
 			SCM_UNDEFINED);
 
 	return list;
