@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: proclist.c,v 1.15 1999/09/29 10:23:04 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -158,7 +158,7 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 		if (which & GLIBTOP_EXCLUDE_IDLE) {
 			glibtop_get_proc_state_s (server, &procstate, pid);
 			if (procstate.flags & (1L << GLIBTOP_PROC_STATE_STATE))
-				if (procstate.state != 'R') continue;
+				if (!(procstate.state & GLIBTOP_PROCESS_RUNNING)) continue;
 		}
 
 		if (which & GLIBTOP_EXCLUDE_SYSTEM) {
