@@ -1,4 +1,6 @@
-/* $Id$ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id: fsusage.c,v 1.4 1999/03/30 14:29:17 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -19,35 +21,35 @@
    along with LibGTop; see the file COPYING. If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
-*/
+ */
 
 #include <glibtop/fsusage.h>
 
-const char *glibtop_names_fsusage [GLIBTOP_MAX_FSUSAGE] =
+const char *glibtop_names_fsusage[GLIBTOP_MAX_FSUSAGE] =
 {
-	"blocks", "bfree", "bavail", "files", "ffree"
+    "blocks", "bfree", "bavail", "files", "ffree"
 };
 
-const unsigned glibtop_types_fsusage [GLIBTOP_MAX_FSUSAGE] =
-{ 
-	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
-	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG
+const unsigned glibtop_types_fsusage[GLIBTOP_MAX_FSUSAGE] =
+{
+    GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
+    GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG
 };
 
-const char *glibtop_labels_fsusage [GLIBTOP_MAX_FSUSAGE] =
+const char *glibtop_labels_fsusage[GLIBTOP_MAX_FSUSAGE] =
 {
-	N_("Total blocks"),
-	N_("Free blocks"),
-	N_("Available blocks"),
-	N_("Total file nodes"),
-	N_("Free file nodes")
+    N_ ("Total blocks"),
+    N_ ("Free blocks"),
+    N_ ("Available blocks"),
+    N_ ("Total file nodes"),
+    N_ ("Free file nodes")
 };
 
-const char *glibtop_descriptions_fsusage [GLIBTOP_MAX_FSUSAGE] =
+const char *glibtop_descriptions_fsusage[GLIBTOP_MAX_FSUSAGE] =
 {
-	N_("Total blocks"),
-	N_("Free blocks available to the superuser"),
-	N_("Free blocks available to non-superusers"),
-	N_("Total file nodes"),
-	N_("Free file nodes")
+    N_ ("Total blocks"),
+    N_ ("Free blocks available to the superuser"),
+    N_ ("Free blocks available to non-superusers"),
+    N_ ("Total file nodes"),
+    N_ ("Free file nodes")
 };
