@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: glibtop_machine.h,v 1.9 1999/06/07 04:13:01 dave Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -64,9 +64,13 @@ struct _glibtop_machine
     int ticks;			/* clock ticks, as returned by sysconf() */
     unsigned long long boot;	/* boot time, although it's ui32 in kstat */
     void *libproc;		/* libproc handle */
+#if GLIBTOP_SOLARIS_RELEASE >= 560
     void (*objname)(void *, uintptr_t, const char *, size_t);
     struct ps_prochandle *(*pgrab)(pid_t, int, int *);
     void (*pfree)(void *);
+#else
+    void *filler[3];
+#endif
 };
 
 END_LIBGTOP_DECLS
