@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: open.c,v 1.15 1999/10/17 21:38:38 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -72,7 +72,7 @@ glibtop_get_kstats(glibtop *server)
 	   life time of a process, but let's hope that's just an error in
 	   the documentation. */
 
-	if(nproc_same = new_ncpu == server->ncpu)
+	if((nproc_same = new_ncpu) == server->ncpu)
 	{
 	    int checked, i;
 	    char cpu[20];
@@ -205,6 +205,8 @@ glibtop_open_s (glibtop *server, const char *program_name,
 
     /* Now let's have a bit of magic dust... */
 
+#if GLIBTOP_SOLARIS_RELEASE >= 560
+
     dl = dlopen("/usr/lib/libproc.so", RTLD_LAZY);
     server->machine.libproc = dl;
     if(dl)
@@ -226,5 +228,6 @@ glibtop_open_s (glibtop *server, const char *program_name,
        server->machine.pgrab = NULL;
        server->machine.pfree = NULL;
     }
+#endif
     server->machine.me = getpid();
 }
