@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: proclist.c,v 1.8 1999/09/28 03:53:08 dave Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -77,8 +77,11 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 	{
 	   if(mask)
 	   {
+#ifdef HAVE_PROCFS_H
 	      struct psinfo psinfo;
-
+#else
+	      struct prpsinfo psinfo;
+#endif
 	      if(glibtop_get_proc_data_psinfo_s(server, &psinfo, pid))
 		 return NULL;
 	      if(mask & GLIBTOP_EXCLUDE_IDLE && !psinfo.pr_pctcpu)
@@ -130,11 +133,12 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 
 #ifdef HAVE_PROCFS_H
 
-		/* Can we skip it based on the request? Solaris 2.6
-		   has ruid and rgid in struct stat. Solaris 7 has euid
-		   and egid. We'll ignore 2.6 for now */
+		/* Can we skip it based on the request? We have
+		   RUID and RGID in struct stat. But we can't do it
+		   like this for LP64 process, because stat() will fail.
+		   XXX Unimplemented for now */
 
-		if(!mask && which == GLIBTOP_KERN_PROC_UID)
+		if(!mask && which == GLIBTOP_KERN_PROC_RUID)
 		{
 		   sprintf (buffer, "/proc/%d", pid);
 		   if (s_stat (buffer, &statb)) continue;
@@ -144,7 +148,7 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 		   if(statb.st_uid != arg) continue;
 		}
 
-		if(which != GLIBTOP_KERN_PROC_ALL)
+		if(mask || which != GLIBTOP_KERN_PROC_ALL)
 		{
 		   struct psinfo psinfo;
 
@@ -156,8 +160,8 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 			 continue;
 		      if(mask & GLIBTOP_EXCLUDE_SYSTEM && psinfo.pr_flag & SSYS)
 			 continue;
-		      if(mask & GLIBTOP_EXCLUDE_NOTTY &&
-			        psinfo.pr_ttydev == PRNODEV)
+		      if(mask & GLIBTOP_EXCLUDE_NOTTY
+			 && psinfo.pr_ttydev == PRNODEV)
 			 continue;
 		   }
 		   switch(which)
@@ -177,7 +181,7 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 		      case GLIBTOP_KERN_PROC_RUID:    if(psinfo.pr_uid != arg)
 						         continue;
 						      break;
-		      default:			      continue;
+		      default:			      break;
 		   }
 		}
 #endif
